==> apache-camel-4.11.0-src.zip: apache-camel-4.11.0/core/camel-core-reifier/src/main/java/org/apache/camel/reifier/validator/EndpointValidatorReifier.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.reifier.validator;

import org.apache.camel.CamelContext;
import org.apache.camel.Endpoint;
import org.apache.camel.ExchangePattern;
import org.apache.camel.model.validator.EndpointValidatorDefinition;
import org.apache.camel.model.validator.ValidatorDefinition;
import org.apache.camel.processor.SendProcessor;
import org.apache.camel.processor.validator.ProcessorValidator;
import org.apache.camel.spi.Validator;

public class EndpointValidatorReifier extends ValidatorReifier<EndpointValidatorDefinition> {

    public EndpointValidatorReifier(CamelContext camelContext, ValidatorDefinition definition) {
        super(camelContext, (EndpointValidatorDefinition) definition);
    }

    @Override
    protected Validator doCreateValidator() {
        Endpoint endpoint = definition.getUri() != null
                ? camelContext.getEndpoint(definition.getUri()) : lookupByNameAndType(definition.getRef(), Endpoint.class);
        SendProcessor processor = new SendProcessor(endpoint, ExchangePattern.InOut);
        return new ProcessorValidator(camelContext).setProcessor(processor).setType(definition.getType());
    }

}

==> apache-camel-4.14.5-src.zip: apache-camel-4.14.5/core/camel-core-reifier/src/main/java/org/apache/camel/reifier/validator/EndpointValidatorReifier.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.reifier.validator;

import org.apache.camel.CamelContext;
import org.apache.camel.Endpoint;
import org.apache.camel.ExchangePattern;
import org.apache.camel.model.validator.EndpointValidatorDefinition;
import org.apache.camel.model.validator.ValidatorDefinition;
import org.apache.camel.processor.SendProcessor;
import org.apache.camel.processor.validator.ProcessorValidator;
import org.apache.camel.spi.Validator;

public class EndpointValidatorReifier extends ValidatorReifier<EndpointValidatorDefinition> {

    public EndpointValidatorReifier(CamelContext camelContext, ValidatorDefinition definition) {
        super(camelContext, (EndpointValidatorDefinition) definition);
    }

    @Override
    protected Validator doCreateValidator() {
        Endpoint endpoint = definition.getUri() != null
                ? camelContext.getEndpoint(definition.getUri()) : lookupByNameAndType(definition.getRef(), Endpoint.class);
        SendProcessor processor = new SendProcessor(endpoint, ExchangePattern.InOut);
        return new ProcessorValidator(camelContext).setProcessor(processor).setType(parseString(definition.getType()));
    }

}
